@@ -293,18 +293,29 @@ class Base(Controller):
         import pprint as pp
 
         if self.app.pargs.text=='ls':
-            # pp.pprint(list_models())
             import pandas as pd
             pd.set_option('display.max_rows', 500)
             
             
             data = list_models()['data']
             df = pd.DataFrame.from_dict(data)
-            print(df)
+            
+            if self.app.pargs.model != 'all':
+                # check if each row contains the model string
+                df = df[df['root'].str.contains(self.app.pargs.model)]
+                
+                print(df)
+            else:
+                print(df)
+                
         else:
             suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions, self.app.pargs.model)
-            pp.pprint(suggestions)
-
+            try:
+                text = suggestions['choices'][0]['text']
+                pp.pprint(suggestions)
+                print('Suggestion: \n', text)
+            except:
+                print('Exception: ', suggestions)
 
     @ex(
         help='Monitor lack of GPU activity. When there is none, runs -job',
