@@ -4,6 +4,7 @@ import os
 # import request
 import pandas as pd
 import time
+import sys
 pd.options.display.width = 0
 
 # pandas set max column width
@@ -18,13 +19,75 @@ def user_select_option(message, options):
     index = int(input("Enter choice (default 0): ") or 0)
     return option_lst[index]
 
-def get_client():
-    with open(os.path.expanduser('~/.dt_config.json')) as f:
+def get_oauth_token(config):
+    '''Get an OAuth token from Asana'''
+    asana_client_id = config['asana_client_id']
+    asana_client_secret = config['asana_client_secret']
+    # create a client with the OAuth credentials:
+    client = asana.Client.oauth(
+        client_id=asana_client_id,
+        client_secret=asana_client_secret,
+        # this special redirect URI will prompt the user to copy/paste the code.
+        # useful for command line scripts and other non-web apps
+        redirect_uri='urn:ietf:wg:oauth:2.0:oob'
+    )
+
+    # get an authorization URL:
+    (url, state) = client.session.authorization_url()
+    try:
+        # in a web app you'd redirect the user to this URL when they take action to
+        # login with Asana or connect their account to Asana
+        import webbrowser
+        webbrowser.open(url)
+    except Exception as e:
+        print("Open the following URL in a browser to authorize:")
+        print(url)
+
+    print("Copy and paste the returned code from the browser and press enter:")
+
+    code = sys.stdin.readline().strip()
+    # exchange the code for a bearer token
+    token = client.session.fetch_token(code=code)
+
+    print("token=", json.dumps(token))
+    print("authorized=", client.session.authorized)
+    # print("me=", client.users.me())
+
+    # normally you'd persist this token somewhere
+    os.environ['ASANA_TOKEN'] = json.dumps(token) # (see below)
+    
+    # save token to ~/.dt_config.json
+    with open(os.path.expanduser('~/.dt_config.json'),"r+") as f:
         config = json.load(f)
-        api_key = config['asana_api_key']
+        config['asana_token'] = token
+        # overwrite json file
+        f.seek(0)
+        f.write(json.dumps(config, indent=4))
+        f.truncate()
         
-    # create asana client
-    client = asana.Client.access_token(api_key)
+    return token, client
+
+
+def get_client(oauth=False):
+    if not oauth:
+        with open(os.path.expanduser('~/.dt_config.json')) as f:
+            config = json.load(f)
+            api_key = config['asana_api_key']
+            
+        # create asana client
+        client = asana.Client.access_token(api_key)
+    else:
+        with open(os.path.expanduser('~/.dt_config.json')) as f:
+            config = json.load(f)
+        
+        client = asana.Client.access_token(config['asana_token']['access_token'])
+        if client.session.authorized == False:
+            print("Token expired, getting new token")
+            token, client = get_oauth_token(config)
+        else:
+            print("Token is still valid")     
+            client = asana.Client.access_token(config['asana_token']['access_token'])
+            
     return client
 
 
@@ -51,7 +114,7 @@ def asana_list_todos(workspace_name,filtering):
         
 def asana_get_todos(workspace_name,filtering):
      # read api key from ~/.dt_config.json
-    client = get_client()
+    client = get_client(True)
     (url, state) = client.session.authorization_url()
         
     me = client.users.me()
